@@ -18,12 +18,8 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GEDIT_WINDOW_H__
-#define __GEDIT_WINDOW_H__
-
-#include <gtksourceview/gtksource.h>
-#include <gio/gio.h>
-#include <gtk/gtk.h>
+#ifndef GEDIT_WINDOW_H
+#define GEDIT_WINDOW_H
 
 #include <gedit/gedit-tab.h>
 #include <gedit/gedit-message-bus.h>
@@ -80,21 +76,6 @@ GType 		 gedit_window_get_type 			(void) G_GNUC_CONST;
 GeditTab	*gedit_window_create_tab		(GeditWindow         *window,
 							 gboolean             jump_to);
 
-GeditTab	*gedit_window_create_tab_from_location	(GeditWindow             *window,
-							 GFile                   *location,
-							 const GtkSourceEncoding *encoding,
-							 gint                     line_pos,
-							 gint                     column_pos,
-							 gboolean                 create,
-							 gboolean                 jump_to);
-
-GeditTab	*gedit_window_create_tab_from_stream	(GeditWindow             *window,
-							 GInputStream            *stream,
-							 const GtkSourceEncoding *encoding,
-							 gint                     line_pos,
-							 gint                     column_pos,
-							 gboolean                 jump_to);
-
 void		 gedit_window_close_tab			(GeditWindow         *window,
 							 GeditTab            *tab);
 
@@ -141,7 +122,6 @@ GeditMessageBus	*gedit_window_get_message_bus		(GeditWindow         *window);
 /*
  * Non exported functions
  */
-GtkWidget	*_gedit_window_get_multi_notebook	(GeditWindow         *window);
 GtkWidget	*_gedit_window_get_notebook		(GeditWindow         *window);
 
 GMenuModel	*_gedit_window_get_hamburger_menu	(GeditWindow         *window);
@@ -152,10 +132,14 @@ void             _gedit_window_move_tab_to_new_tab_group(GeditWindow         *wi
                                                          GeditTab            *tab);
 gboolean	 _gedit_window_is_removing_tabs		(GeditWindow         *window);
 
-GFile		*_gedit_window_get_default_location 	(GeditWindow         *window);
+const gchar	*_gedit_window_get_file_chooser_folder_uri
+							(GeditWindow          *window,
+							 GtkFileChooserAction  action);
 
-void		 _gedit_window_set_default_location 	(GeditWindow         *window,
-							 GFile               *location);
+void		 _gedit_window_set_file_chooser_folder_uri
+							(GeditWindow          *window,
+							 GtkFileChooserAction  action,
+							 const gchar          *folder_uri);
 
 void		 _gedit_window_fullscreen		(GeditWindow         *window);
 
@@ -169,6 +153,6 @@ GFile		*_gedit_window_pop_last_closed_doc	(GeditWindow         *window);
 
 G_END_DECLS
 
-#endif  /* __GEDIT_WINDOW_H__  */
+#endif  /* GEDIT_WINDOW_H  */
 
 /* ex:set ts=8 noet: */
